/*
 *  xfmedia - simple gtk2 media player based on xine
 *
 *  Copyright (c) 2004-2005 Brian Tarricone, <bjt23@cornell.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; version 2 of the License ONLY.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFMEDIA_MAIN_H___
#define __XFMEDIA_MAIN_H___

#include <glib.h>

#include "mainwin.h"

G_BEGIN_DECLS

typedef enum {
	XFMEDIA_QUIT_MODE_EXT = 0,
	XFMEDIA_QUIT_MODE_MAINWIN_DESTROY,
	XFMEDIA_QUIT_MODE_VWIN_DESTROY
} XfmediaQuitMode;

void xfmedia_quit(XfmediaMainwin *mwin, XfmediaQuitMode quit_mode);

G_END_DECLS

#endif
